@@ -5,7 +5,6 @@ class PanoramaImage(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/panorama-images'
         
     
@@ -17,10 +16,10 @@ class PanoramaImage(v1Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}')
             self.value = self.value['panoramaImage']
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['panoramaImages']
         
         return self
@@ -32,7 +31,7 @@ class PanoramaImage(v1Object):
         To post the updates that have been made to self.value
         """
         
-        response_json = self._client.post(self._api, self._endpoint, self.value)
+        response_json = self._client._post(self._api, self._endpoint, self.value)
         self.value['id'] = response_json['panoramaImage']['id']
         
         return self
\ No newline at end of file
