@@ -5,7 +5,6 @@ class WorkorderItem(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/work-order-items'
         
     
@@ -16,10 +15,10 @@ class WorkorderItem(v1Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/filter/ids/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/filter/ids/{id}')
             self.value = self.value['workOrderItems'][0]
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['workOrderItems']
         
         return self
@@ -29,7 +28,7 @@ class WorkorderItem(v1Object):
         To post the updates that have been made to self.value
         """
         
-        response_json = self._client.post(self._api, self._endpoint, self.value)
+        response_json = self._client._post(self._api, self._endpoint, self.value)
         self.value['id'] = response_json['workOrderItems']['id']
         
         return self
